:mod:`API`
----------------------------

``model_catalogs`` Python API
===========================

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Documentation


.. automodule:: model_catalogs.model_catalogs
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:
